from django.apps import apps
from prometheus_client.core import CounterMetricFamily, REGISTRY

class ModelCountCollector(object):

    def collect(self):
        counter = CounterMetricFamily('model_count', 'Number of objects per model', labels=['model', 'app'])
        yield counter
        if not apps.models_ready or not apps.apps_ready:
            return
        for app_name, app_config in apps.app_configs.items():
            for model in app_config.get_models():
                counter.add_metric([model.__name__, app_name], model.objects.count())
        yield counter

REGISTRY.register(ModelCountCollector())